@@ -10,6 +10,8 @@ from requests.exceptions import Timeout
 import sys
 import pendulum
 import re
+from pyhabitat import on_termux, on_windows, is_pyz, is_elf, is_pipx, matplotlib_is_available_for_gui_plotting, edit_textfile
+
 
 try:
     import colorama # explicitly added so for the shiv build
@@ -23,7 +25,6 @@ except ImportError:
 from pipeline.time_manager import TimeManager
 from pipeline.create_sensors_db import get_db_connection, create_packaged_db, reset_user_db # get_user_db_path, ensure_user_db, 
 from pipeline.api.eds import demo_eds_webplot_point_live, EdsClient, load_historic_data, EdsLoginException, demo_eds_save_point_export
-from pipeline.environment import is_termux, is_windows, is_pyz, is_elf, is_pipx, matplotlib_enabled, open_text_file_in_default_app
 from pipeline.security_and_config import get_eds_api_credentials, get_external_api_credentials, get_eds_db_credentials, get_all_configured_urls, get_configurable_plant_name, init_security, CONFIG_PATH
 from pipeline.termux_setup import setup_termux_install, cleanup_termux_install
 from pipeline.windows_setup import setup_windows_install, cleanup_windows_install
@@ -32,14 +33,17 @@ from pipeline.plotbuffer import PlotBuffer
 from pipeline.version_info import  PIP_PACKAGE_NAME, PIPELINE_VERSION, __version__, get_package_version, get_package_name
 #from pipeline.helpers import setup_logging
 
-# --- TERMUX SETUP HOOK ---
+# --- SETUP / INSTALL HOOK ---
 # This runs on every command (including --version and --help or without sub commands), 
 # but the function's internal logic
 # ensures the shortcut file is only created once in the Termux environment.
-if is_termux():
+#-- SUPPRESS with "False and" as of 0.3.53 - automaic installation on every run is invasive and is annyoring for troubleshooting, like if the user changes the .shortcut/filename
+#-- user may directly run 'install' command
+if False and on_termux():
     setup_termux_install()
-elif is_windows():
+elif False and on_windows():
     setup_windows_install()
+# --- end SETUP / INSTALL HOOK ---
 
 # -- Versioning --
 def print_version(value: bool):
@@ -150,9 +154,9 @@ def defaultplant(
 def trend(
     idcs: list[str] = typer.Argument(None, help="Provide known idcs values that match the given zd."), # , "--idcs", "-i"
     starttime: str = typer.Option(None, "--start", "-s", help="Identify start time. Use any reasonable format, to be parsed automatically. If you must use spaces, use quotes."),
-    endtime: str = typer.Option(None, "--end", "-end", help="Identify end time. Use any reasonable format, to be parsed automatically. If you must use spaces, use quotes."),
+    endtime: str = typer.Option(None, "--end", "-e", help="Identify end time. Use any reasonable format, to be parsed automatically. If you must use spaces, use quotes."),
+    days: float = typer.Option(None, "--days", "-ds", help="Identify end time. Use any reasonable format, to be parsed automatically. If you must use spaces, use quotes."),
     plant_name: str = typer.Option(None, "--plantname", "-pn", help = "Provide the EDS ZD for your credentials."),
-    #workspacename: str = typer.Option(None,"--workspace","-w", help = "Provide the name of the workspace you want to use, for the secrets.yaml credentials and for the timezone config. If a start time is not provided, the workspace queries can checked for the most recent successful timestamp. "),
     print_csv: bool = typer.Option(False,"--print-csv","-p",help = "Print the CSV style for pasting into Excel."),
     step_seconds: int = typer.Option(None, "--step-seconds", help="You can explicitly provide the delta between datapoints. If not, ~400 data points will be used, based on the nice_step() function."), 
     webplot: bool = typer.Option(False,"--webplot","-w",help = "Use a browser-based plot instead of local (matplotlib). Useful for remote servers without display."),
@@ -218,19 +222,10 @@ def trend(
     session = EdsClient.login_to_session_with_api_credentials(api_credentials)
 
     points_data = EdsClient.get_points_metadata(session, filter_iess=iess_list)
-    
-    
-    if endtime is None:
-        dt_finish = pendulum.from_timestamp(helpers.get_now_time_rounded())
-        print(f"No endtime provided, so defaulting to now: {dt_finish.to_datetime_string()}")
-    else:
-        dt_finish = pendulum.parse(helpers.sanitize_date_input(endtime), strict=False)
-    if starttime is None:
-        days_past = 2
-        dt_start = dt_finish.subtract(days=days_past) # default to 2 days ago
-        print(f"No starttime provided, so defaulting to {days_past} days before endtime: {dt_start.to_datetime_string()}")
-    else:
-        dt_start = pendulum.parse(helpers.sanitize_date_input(starttime), strict=False)
+
+
+    # --- Assess time range --
+    dt_start, dt_finish = helpers.asses_time_range(starttime=starttime, endtime=endtime, days=days)
 
     # Should automatically choose time step granularity based on time length; map 
     if step_seconds is None:
@@ -269,7 +264,7 @@ def trend(
     # Once the loop is done, you can call your show_static function
     # with the single, populated data_buffer.
 
-    if not matplotlib_enabled() or webplot:
+    if webplot or not matplotlib_is_available_for_gui_plotting():
         from pipeline import gui_plotly_static
         #from pipeline import gui_plotly_static_backup_06Oct25 as gui_plotly_static
         #gui_fastapi_plotly_live.run_gui(data_buffer)
@@ -307,7 +302,7 @@ def configure_credentials(
     """
     if textedit:
         typer.echo(F"Config filepath: {CONFIG_PATH}")
-        open_text_file_in_default_app(CONFIG_PATH)
+        edit_textfile(CONFIG_PATH)
         return
             
     typer.echo("")
@@ -366,15 +361,15 @@ def list_workspaces():
     for name in workspaces_list:
         typer.echo(f" - {name}")
 
-@app.command()
-def install(
+@app.command(name="setup", help="Setup touch point like widget entries, context menu items, and AppData folder for system integration. Based on environment.")
+def setup_integration(
     uninstall: bool = typer.Option(False,"--uninstall","-un",help = "Remove the installation artifacts for the current operating system."),
     upgrade: bool = typer.Option(False, "--upgrade", "-up", help = "Uppgrades will be forece, namely shortcut scripts on Termux will be overwritten even if they already exist."),
     debug: bool = typer.Option(False, "--debug", "-d", help = "Show debugging output and do not actually perform any installation or uninstallation actions.")
 ):
     """
-    Windows: Uninstall the registry context-menu item, the launcher BAT, and the AppData folder
-    Termux: Remove the scripts from the .shortcuts/ folder.
+    Windows: Un/install the registry context-menu item, the launcher BAT, and the AppData folder
+    Termux: Add / remove the scripts from the .shortcuts/ folder.
     """
 
     if debug:
@@ -385,21 +380,24 @@ def install(
         return
     
     if uninstall:
-        if is_windows():
+        if on_windows():
             if typer.confirm("Are you sure you want to uninstall the registry context-menu item, the launcher BAT, and empty out the AppData folder?"):
                 cleanup_windows_install()
-        elif is_termux():
+        elif on_termux():
             cleanup_termux_install()
         return
 
-    if is_windows():
+    if on_windows():
         typer.echo("AppData will be set up explicity and a content menu item will be added to your Registry.")
         setup_windows_install()
-    elif is_termux():
+    elif on_termux():
         typer.echo("Scripts will now be added to the $HOME/.shortcuts/ directory for launching from the Termux Widget.")
         setup_termux_install(force=upgrade)
-        typer.confirm("Setup complete. You may need to restart Termux for the changes to take effect.")
-
+        typer.echo("Update complete.")
+        typer.echo(f"\n{get_package_name()} --version")
+        typer.secho(f"{get_package_name()} {get_package_version()}", fg=typer.colors.GREEN, bold=True)
+        typer.echo("\n")
+        input("Press Enter to exit...") # moved to internal of setup_termux_install()
 
 
 @app.command()
