@@ -6,16 +6,17 @@ import plotly.offline as pyo
 import webbrowser
 import tempfile
 import threading
-from pipeline.environment import is_termux
+from pyhabitat import on_termux
 import http.server
 import time
 from pathlib import Path
 import os
 import subprocess
 from urllib.parse import urlparse
-import numpy as np
 
 from pipeline.web_utils import launch_browser
+from pipeline.plottools import normalize, normalize_ticks, get_ticks_array_n
+
 
 PLOTLY_THEME = 'seaborn'
 """
@@ -32,8 +33,8 @@ COLORS = [
     'rgba(23, 190, 207, 0.7)'   # #17becf
 ] """  
 COLORS = []
-font_size = 24 if is_termux() else 16
-#font_size = 24
+font_size = 20 if on_termux() else 14
+
 
 buffer_lock = threading.Lock()  # Optional, if you want thread safety
 
@@ -83,37 +84,6 @@ class MockBuffer:
         }
 #plot_buffer = MockBuffer()
 
-# --- Helper Function for Normalization ---
-# It's good practice to have this as a separate, robust function.
-# Normalization function (scaling to range [0, 1])
-# Returns the normalized array, min, and max of the original data
-def normalize(data):
-    """Normalizes a numpy array to the range [0, 1], 
-    and return max and min."""
-    min_val = np.min(data)
-    max_val = np.max(data)
-    # Handle the case where max_val == min_val to avoid division by zero
-    if max_val == min_val:
-        return np.zeros_like(data), min_val, max_val
-    return (data - min_val) / (max_val - min_val), min_val, max_val
-
-# Function to normalize a set of ticks based on the original data's min/max
-def normalize_ticks(ticks, data_min, data_max):
-    # Handle the case where max_val == min_val
-    ticks_arr = np.asarray(ticks, dtype=np.float64)
-    if not np.isfinite(data_min) or not np.isfinite(data_max):
-        return np.array(ticks_arr - float(data_min)) / (float(data_max) - float(data_min))
-    if data_max == data_min:
-        return np.zeros_like(ticks_arr)
-    return np.array((ticks_arr - float(data_min)) / (float(data_max) - float(data_min)))
-
-def get_ticks_array_n(y_min, y_max, steps):
-    # Calculate the step size
-    step = (y_max - y_min) / steps
-    array_tick_location = []
-    for i in range(steps+1): 
-        array_tick_location.append(y_min+i*step)
-    return array_tick_location
 
 def assess_unit_stats(data):
     """
@@ -124,11 +94,13 @@ def assess_unit_stats(data):
     unit_stats = {}
     for label, series in data.items():
         unit = series["unit"]
-        y_data = np.array(series["y"], dtype="float")
+        #y_data = np.array(series["y"], dtype="float")
+        y_data = [float(x) for x in series["y"]]
         
         #if not np.any(y_data): continue # Skip empty series
 
-        current_min, current_max = np.min(y_data), np.max(y_data)
+        #current_min, current_max = np.min(y_data), np.max(y_data)
+        current_min, current_max = min(y_data), max(y_data)
         
         if unit not in unit_stats:
             unit_stats[unit] = {"min": current_min, "max": current_max}
@@ -166,9 +138,16 @@ def y_normalize_global(y_original,unit_stats, unit=None):
     # VISUAL NORMALIZATION: Normalize using the GLOBAL range for the unit.
     # This ensures all traces on the same axis share the same scale.
     if global_max == global_min:
-        y_normalized = np.zeros_like(y_original)
+        #y_normalized = np.zeros_like(y_original)
+        y_normalized = [0.0] * len(y_original)
+        
     else:
-        y_normalized = (y_original - global_min) / (global_max - global_min)
+        #y_normalized = (y_original - global_min) / (global_max - global_min)
+        range_val = global_max - global_min
+        y_normalized = [
+            (y_val - global_min) / range_val
+            for y_val in y_original
+        ]
     return y_normalized
 
 def build_y_axis(y_min, y_max,axis_index,axis_label,tick_count = 10):
@@ -182,13 +161,12 @@ def build_y_axis(y_min, y_max,axis_index,axis_label,tick_count = 10):
     ticktext = [f"{t:.0f}" for t in original_ticks]
     tickvals=normalize_ticks(original_ticks, y_min, y_max) # Normalized positions
 
-    pos = (0.0025*axis_index**2)+(axis_index)*0.08
+    pos = (0.0025*axis_index**2)+(axis_index)*0.1
     overlaying_prop = "y" if axis_index > 0 else None
     
     #pos = (axis_index)
     #pos= 0
     yaxis_dict=dict(
-        #title=axis_label,
         title=dict(text=axis_label, standoff=10), # Use dict for better control
         #overlaying="y", # or "no", no known difference # suppress
         overlaying = overlaying_prop,
@@ -235,11 +213,13 @@ def show_static(plot_buffer):
     
     for i, (label, series) in enumerate(data.items()):
         
-        y_original = np.array(series["y"],dtype="float")
+        #y_original = np.array(series["y"],dtype="float")
+        y_original = [float(x) for x in series["y"]]
         unit = series["unit"]
         # 1. VISUAL NORMALIZATION: Normalize y-data for plotting
         #y_normalized , y_min, y_max = normalize(y_original)
-        if y_original.size == 0: continue
+        #if y_original.size == 0: continue
+        if len(y_original)==0: continue
         y_normalized = y_normalize_global(y_original,unit_stats, unit)
         
         current_axis_idx = unit_to_axis_index[unit]
@@ -267,7 +247,7 @@ def show_static(plot_buffer):
 
     # --- Figure Creation and Layout Updates ---
     final_layout = {
-        'title': "EDS Data Plot (Static, Normalized)",
+        #'title': "EDS Data Plot (Static)", # shows large on mobile, not very useful
         'template':PLOTLY_THEME,
         'showlegend': True,
         # Set the plot area to span the full width of the figure as requested
@@ -281,7 +261,7 @@ def show_static(plot_buffer):
             bgcolor='rgba(255, 255, 255, 0.1)', # semi transparent background
             bordercolor='grey',
             borderwidth=1,
-            title="Curves"
+            #title="Curves"
         ),
         'margin': dict(l=20, r=20, t=50, b=40) # Add on;y a little padding around the whole figure - this increases the size compared to the default
     }
@@ -308,14 +288,14 @@ def show_static(plot_buffer):
     original_cwd = os.getcwd() # Save original CWD to restore later if needed
 
     # --- Inject the button based on environment ---
-    is_termux_mode = is_termux()
-    tmp_path = inject_buttons(tmp_path, is_server_mode=is_termux_mode)
+    on_termux_mode = on_termux()
+    tmp_path = inject_buttons(tmp_path, is_server_mode=on_termux_mode)
 
     
     os.chdir(str(tmp_dir))
 
     # If running in Windows, open the file directly
-    if not is_termux():
+    if not on_termux():
         webbrowser.open(f"file://{tmp_file.name}")
         # Restore CWD before exiting
         os.chdir(original_cwd) 
@@ -569,4 +549,4 @@ def inject_buttons(tmp_path: Path, is_server_mode: bool) -> Path:
 
 if __name__ == '__main__':
     # This block is for testing the plotting logic, assuming a working launch_browser
-    show_static(MockBuffer())
\ No newline at end of file
+    show_static(MockBuffer())
