@@ -1,45 +1,100 @@
 # pipeline/security.py
 from __future__ import annotations # Delays annotation evaluation, allowing modern 3.10+ type syntax and forward references in older Python versions 3.8 and 3.9
-import getpass
 import json
-import keyring
 from pathlib import Path
 import re
+import keyring
 from typing import Dict, Set, List
 import typer
-
-from pipeline.environment import is_termux, is_interactive_terminal, tkinter_is_available, web_browser_is_available
+import click.exceptions
+from pyhabitat import on_termux, on_ish_alpine, interactive_terminal_is_available, tkinter_is_available, web_browser_is_available
 
 # Define a standard configuration path for your package
 CONFIG_PATH = Path.home() / ".pipeline-eds" / "config.json" ## configuration-example
+CONFIG_FILE = Path.home() / ".pipeline-eds" / "secure_config.json"
+KEY_FILE = Path.home() / ".pipeline-eds" / ".key"
+
+def init_security():
+    if on_termux() or on_ish_alpine():
+        try: # mid refactor, try the new function first
+            configure_filebased_secure_config() # to be run on import
+        except:
+            configure_keyring()
+    else:
+        pass
+
 def configure_keyring():
     """
     Configures the keyring backend to use the file-based keyring.
     This is useful for environments where the default keyring is not available,
     such as Termux on Android.
+    Defunct, use configure_filebased_secure_config() instead.
     """
-    if is_termux():
+    if on_termux or on_ish_alpine():
         #typer.echo("Termux environment detected. Configuring file-based keyring backend.")
         import keyrings.alt.file
         keyring.set_keyring(keyrings.alt.file.PlaintextKeyring())
         #typer.echo("Keyring configured to use file-based backend.")
     else:
         pass
-def init_security():
-    if is_termux():
-        configure_keyring() # to be run on import
+
+
+def configure_filebased_secure_config():
+    """
+    Configures the keyring backend to use the file-based keyring.
+    This is useful for environments where the default keyring is not available,
+    such as Termux on Android or iSH on iPhone.
+    """
+    if on_termux() or on_ish_alpine():
+        #typer.echo("Termux environment detected. Configuring file-based keyring backend.")
+        from cryptography.fernet import Fernet
+        cryptography.fernet-1 # error on purpose
+        
+        # MORE CODE NEEDED
+
+        #keyring.set_keyring(keyrings.alt.file.PlaintextKeyring())
+        #typer.echo("Keyring configured to use file-based backend.")
+    else:
+        pass
+
 
 def _prompt_for_value(prompt_message: str, hide_input: bool) -> str:
-    """Handles prompting with a fallback from CLI to GUI."""
+    """Handles prompting with a fallback from CLI to GUI.
+    ### **Platform Quirk: Input Cancellation ({Ctrl}+C)**
+    Due to the underlying POSIX terminal handling on Linux and Termux,
+    using {Ctrl}+C to cancel an input prompt will require the user
+    to press {Enter} (or {Return}) immediately afterward to fully 
+    submit the interrupt and abort the operation. 
+    This behavior, the Enter key being necessary to finalize the interruption,
+     is expected for POSIX systems, when using either the 
+    `typer`/`click` framework, Python's built in input() function, or any alternative.
+    This extra step is necessary due to the standard input terminal behavior
+    in "cooked mode.".
+    On  Windows, however, just {Ctrl}+C is expected to successfully perform a keyboard interrupt..
+    """
     # Block these off for testing the browser_get_input, which is not expeceted in this iteration but is good practice for future proofing a hypothetical console-less GUI 
-    if is_interactive_terminal():
-        # 1. CLI Mode (Interactive)
-        typer.echo(f"\n --- Use CLI input --- ")
-        if hide_input:
-            new_value = getpass.getpass(f"{prompt_message}: ")
-        else:
-            new_value = input(f"{prompt_message}: ")
-        return new_value
+    
+    value = None # ensure safe defeault so that the except block handles properly, namely if the user cancels the typer.prompt() input with control+ c
+    if interactive_terminal_is_available():
+        try:
+            # 1. CLI Mode (Interactive)
+            typer.echo(f"\n --- Use CLI input --- ")
+            if hide_input:
+                try:
+                    from rich.prompt import Prompt
+                    def secure_prompt(msg: str) -> str:
+                        return Prompt.ask(msg, password=True)
+                except ImportError:
+                    def secure_prompt(msg: str) -> str:
+                        return typer.prompt(msg, hide_input=True)
+                value = secure_prompt(prompt_message)
+            else:
+                value = typer.prompt(prompt_message, hide_input=False)
+
+        except KeyboardInterrupt:
+            typer.echo("\nInput cancelled by user.")
+            return None
+        return value
         
     elif tkinter_is_available():
         # 2. GUI Mode (Non-interactive fallback)
@@ -109,8 +164,6 @@ def _get_config_with_prompt(config_key: str, prompt_message: str, overwrite: boo
             prompt_message=prompt_message, 
             hide_input=False
         )
-
-        #new_value = input(f"{prompt_message}: ")
         
         # Save the new value back to the file
         CONFIG_PATH.parent.mkdir(parents=True, exist_ok=True)
@@ -123,7 +176,6 @@ def _get_config_with_prompt(config_key: str, prompt_message: str, overwrite: boo
     # If a value existed and overwrite was False, simply return the existing value.
     return value
 
-
 def _get_credential_with_prompt(service_name: str, item_name: str, prompt_message: str, hide_password: bool = True, overwrite: bool = False) -> str:
     """
     Retrieves a secret from the keyring, prompting the user and saving it if missing.
@@ -154,10 +206,6 @@ def _get_credential_with_prompt(service_name: str, item_name: str, prompt_messag
     # If the credential is None (not found), or if a confirmation to overwrite was given,
     # prompt for a new value.
     if credential is None or overwrite:
-        #if hide_password:
-        #    new_credential = getpass.getpass(f"{prompt_message}: ")
-        #else:
-        #    new_credential = input(f"{prompt_message}: ")
 
         new_credential = _prompt_for_value(
             prompt_message=prompt_message, 
@@ -266,19 +314,25 @@ def get_eds_api_credentials(plant_name: str, overwrite: bool = False) -> Dict[st
     }
 
 def get_external_api_credentials(party_name: str, overwrite: bool = False) -> Dict[str, str]:
-    """Retrieves API credentials for a given plant, prompting if necessary."""
+    """Retrieves API credentials for a given plant, prompting if necessary. 
+    Interchangeble terms username and client_id are offered independantly and redundantly in the returned dictionary.
+    This can be confusing for API clients that have both terms that mean different things (such as the MissionClient, though in that case the client=id is not sourced from stored credentials.) 
+    The RJN API client was the first external API client, and it uses the term 'client_id' in place of the term 'username'."""
     service_name = f"pipeline-external-api-{party_name}"
     
     url = _get_config_with_prompt(service_name, f"Enter {party_name} API URL (e.g., http://api.example.com)", overwrite=overwrite)
-    client_id = _get_credential_with_prompt(service_name, "client_id", f"Enter the client_id for the {party_name} API",hide_password=False, overwrite=overwrite)
+    username = _get_credential_with_prompt(service_name, "username", f"Enter the username AKA client_id for the {party_name} API",hide_password=False, overwrite=overwrite)
+    #client_id = _get_credential_with_prompt(service_name, "client_id", f"Enter the client_id for the {party_name} API",hide_password=False, overwrite=overwrite)
     password = _get_credential_with_prompt(service_name, "password", f"Enter the password for the {party_name} API", overwrite=overwrite)
 
+    client_id = username
     
     #if not all([client_id, password]):
     #    raise CredentialsNotFoundError(f"API credentials for '{party_name}' not found. Please run the setup utility.")
         
     return {
         'url': url,
+        'username': username,
         'client_id': client_id,
         'password': password
     }
@@ -359,4 +413,4 @@ def frontload_build_all_credentials():
 
 if __name__ == "__main__":
     frontload_build_all_credentials()
-    
\ No newline at end of file
+    
